Coverage for /var/devmt/py/ghmdlib_0.1.0/ghmdlib/__init__.py: 50%

1#!/usr/bin/env python3

2# -*- coding: utf-8 -*-

3"""

4:Purpose: Project initialisation module.

5

6:Platform: Linux/Windows | Python 3.10+

7:Developer: J Berendt

8:Email: development@s3dev.uk

9

10:Comments: n/a

11

12"""

13

14# locals

15 try:

16 from .ghmd import converter

17 from .libs._version import __version__

18 except ImportError:

19 from ghmdlib.ghmd import converter

20 from ghmdlib.libs._version import __version__

21